@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -23,7 +23,6 @@ from typing import (
 )
 from urllib.parse import urljoin
 
-import jsonschema
 from gql import Client
 from qctrlcommons.auth import (
     BearerTokenAuth,
@@ -55,13 +54,6 @@ from ..scripts_utils import (
 
 LOGGER = logging.getLogger(__name__)
 
-_CREDENTIALS_FILE_SCHEMA = {
-    "type": "object",
-    "properties": {"email": {"type": "string"}, "password": {"type": "string"}},
-    "required": ["email", "password"],
-}
-_CREDENTIALS_FILE_PERMISSIONS = "600"
-
 
 def get_jwt_token(api_root: str) -> Tuple[str, str, Callable]:
     """Get Jwt token from file storage.
@@ -107,26 +99,17 @@ def _parse_credentials_file(file_path: str) -> tuple:
     Raises
     ------
     OSError
-        "credentials file does not exist" or "incorrect permissions for credentials file"
+        if credentials file does not exist
     """
 
     if not os.path.isfile(file_path):
         raise OSError(f"credentials file does not exist: {file_path}")
 
-    # check permissions
-    stat = os.stat(file_path)
-    permissions = oct(stat.st_mode)
-
-    if not permissions.endswith(_CREDENTIALS_FILE_PERMISSIONS):
-        raise OSError("incorrect permissions for credentials file")
-
     # get data
     with open(file_path) as json_file:
         data = json_file.read()
         data = json.loads(data)
 
-    # validate data
-    jsonschema.validate(_CREDENTIALS_FILE_SCHEMA, data)
     return data["access_token"], data["refresh_token"]
 
 
