@@ -18,10 +18,7 @@ from typing import Any
 import pytz
 from dateutil.parser import parse
 from qctrlcommons.graph import Graph
-from qctrlcommons.serializers import (
-    DataTypeDecoder,
-    DataTypeEncoder,
-)
+from qctrlcommons.serializers import DataTypeEncoder
 
 from qctrl.builders.graphql_utils.handlers.base import BaseHandler
 from qctrl.builders.graphql_utils.handlers.mixins import ScalarMixin
@@ -33,11 +30,6 @@ def _encode_custom_scalar(value: Any) -> Any:
     return json.dumps(result)
 
 
-def _decode_custom_scalar(value: Any) -> Any:
-    """Decodes a custom scalar value."""
-    return json.loads(value, cls=DataTypeDecoder)
-
-
 def _decode_datetime_scalar(value: str) -> datetime:
     """
     Decode a datetime scalar value.
@@ -52,16 +44,6 @@ def _decode_unix_scalar(value: str) -> datetime:
     return datetime.fromtimestamp(int(value)).astimezone(pytz.utc)
 
 
-class JsonStringScalarHandler(ScalarMixin, BaseHandler):
-    """Custom scalar handler for JsonString."""
-
-    _scalar_name = "JsonString"
-    _scalar_encoder = _encode_custom_scalar
-    _scalar_decoder = _decode_custom_scalar
-    _scalar_allowed_type = str
-    scalar_type_hint = str
-
-
 class DateTimeScalarHandler(ScalarMixin, BaseHandler):
     """Custom scalar handler for DateTime."""
 
@@ -76,7 +58,6 @@ class GraphScalarHandler(ScalarMixin, BaseHandler):
 
     _scalar_name = "Graph"
     _scalar_encoder = _encode_custom_scalar
-    _scalar_decoder = _decode_custom_scalar
     _scalar_allowed_type = Graph
     scalar_type_hint = Graph
 
@@ -86,7 +67,6 @@ class JsonDictScalarHandler(ScalarMixin, BaseHandler):
 
     _scalar_name = "JsonDict"
     _scalar_encoder = _encode_custom_scalar
-    _scalar_decoder = _decode_custom_scalar
     _scalar_allowed_type = dict
     scalar_type_hint = dict
 
