@@ -87,7 +87,7 @@ class ActivityMonitorQuery(StaticQuery):
 
         return {"limit": limit, "offset": offset, "filterBy": filter_by}
 
-    def _format_response(self, response: Dict) -> str:
+    def _format_response(self, response: Dict, *_) -> str:
         actions = (
             f'{"Name":<40} '
             f'{"Status":<10} '
